# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = [
    "TargetInstances",
    "LogLevel",
    "OffTypes",
    "OnOff",
    "Wraps",
    "CoordFrame",
    "RotFrame",
    "RotMode",
    "AccessModes",
    "Planets",
    "Foci",
    "WarningLevel",
    "DetailedStates",
    "TargetTypes",
    "WrapStrategy",
]

import enum


class TargetInstances(enum.IntEnum):
    CURRENT = 1
    NEXT = 2
    PROSPECTIVE = 3


class LogLevel(enum.IntEnum):
    NONE = 1
    FATAL = 2
    ERROR = 3
    WARNING = 4
    INFO = 5
    DEBUG = 6
    VERBOSE = 7


class OffTypes(enum.IntEnum):
    SIMPLE = 1
    TPLANE = 2


class OnOff(enum.IntEnum):
    ON = 1
    OFF = 2


class Wraps(enum.IntEnum):
    CW = 1
    CCW = 2


class CoordFrame(enum.IntEnum):
    FK5 = 1
    ICRS = 2


class RotFrame(enum.IntEnum):
    TARGET = 1
    AZEL = 2
    FIXED = 3


class RotMode(enum.IntEnum):
    FIELD = 1
    SLIT = 2


class AccessModes(enum.IntEnum):
    OPERATOR = 1
    ENGINEER = 2


class Planets(enum.IntEnum):
    MERCURY = 1
    VENUS = 2
    MOON = 3
    MARS = 4
    JUPITER = 5
    SATURN = 6
    URANUS = 7
    NEPTUNE = 8
    PLUTO = 9


class Foci(enum.IntEnum):
    PRIME = 1
    NASMYTH1 = 2
    NASMYTH2 = 3


class WarningLevel(enum.IntEnum):
    NONE = 1
    MINOR = 2
    MAJOR = 3


class DetailedStates(enum.IntEnum):
    NOTTRACKING = 1
    AZEL = 2
    OPENLOOP = 3
    GUIDING = 4


class TargetTypes(enum.IntEnum):
    RADEC = 1
    AZEL = 2
    PLANET = 3
    EPHEM = 4


class WrapStrategy(enum.IntEnum):
    """Defines wrap strategy enumeration.

    NOUNWRAP:
        Do not attempt to unwrap azimuth. If target is unreachable,
        reject the command.
    OPTIMIZE:
        Optimize wrap strategy based on ``raDecTarget.timeOnTarget``.
        It will only attempt to unwrap if time available on target is
        smaller then ``raDecTarget.timeOnTarget``.
    MAXTIMEONTARGET:
        Choose the wrap that maximises time on target.
    """

    NOUNWRAP = 1
    OPTIMIZE = 2
    MAXTIMEONTARGET = 3



import enum


class LaserDetailedState(enum.IntEnum):
    """An enumeration class for handling the TunableLaser's substates.

    These enumerations listed here correspond to the ones found in the
    detailedState enum located in ts_xml under the TunableLaser folder within
    the TunableLaser_Events.xml.

    Attributes
    ----------

    NONPROPAGATING : `int`
        Corresponds to the nonpropgating state.
    PROPAGATINGSTATE : `int`
        Corresponds to the propagating state.

    """

    NONPROPAGATING = 1
    PROPAGATING = 2


class LaserErrorCode(enum.IntEnum):
    """Laser error codes"""

    ASCII_ERROR = 7301
    GENERAL_ERROR = 7302
    TIMEOUT_ERROR = 7303
    HW_CPU_ERROR = 7304



# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = ["DriveState"]

import enum


class AxisState(enum.IntEnum):
    """Axis state."""

    UNKNOWN = 0
    OFF = enum.auto()
    IDLE = enum.auto()
    ENABLED = enum.auto()
    DISCRETE_MOVE = enum.auto()
    JOG_MOVE = enum.auto()
    TRACKING = enum.auto()
    STOPPING = enum.auto()
    FAULT = enum.auto()


class DriveState(enum.IntEnum):
    """Drive state.

    Reported as statusDrive by the low-level controller.
    """

    UNKNOWN = 0
    OFF = enum.auto()
    MOVING = enum.auto()
    STOPPING = enum.auto()
    STOPPED = enum.auto()
    FAULT = enum.auto()


class SubsystemId(enum.IntEnum):
    AZIMUTH_AXIS = 100
    AZIMUTH_DRIVE = 200
    AZIMUTH_CABLE_WRAP = 300
    ELEVATION_AXIS = 400
    ELEVATION_DRIVE = 500
    MAIN_POWER_SUPPLY = 600
    ENCODER_INTERFACE_BOX = 700
    OIL_SUPPLY_SYSTEM = 800
    MIRROR_COVERS = 900
    CAMERA_CABLE_WRAP = 1000
    BALANCE = 1100
    DEPLOYABLE_PLATFORM = 1200
    CABINET = 1300
    LOCKING_PINS = 1400
    MIRROR_COVER_LOCKS = 1500
    AZIMUTH_THERMAL = 1600
    ELEVATION_THERMAL = 1700
    INTERLOCK = 1800
    TOP_END_CHILLER = 2200



# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = [
    "AzimuthCommandedState",
    "AzimuthState",
    "ShutterDoorCommandedState",
    "ShutterDoorState",
]

import enum


class AzimuthCommandedState(enum.IntEnum):
    UNKNOWN = 1
    GOTOPOSITION = 2
    HOME = 3
    STOP = 4


class AzimuthState(enum.IntEnum):
    NOTINMOTION = 1
    MOVINGCW = 2
    MOVINGCCW = 3


class ShutterDoorCommandedState(enum.IntEnum):
    UNKNOWN = 1
    CLOSED = 2
    OPENED = 3
    STOP = 4


class ShutterDoorState(enum.IntEnum):
    CLOSED = 1
    OPENED = 2
    PARTIALLYOPENED = 3
    OPENING = 4
    CLOSING = 5



# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = [
    "OfflineDetailedState",
    "ImageReadinessDetailedState",
    "CalibrationDetailedState",
    "ShutterDetailedState",
    "CCSCommandState",
    "RaftsDetailedState",
    "CCDType",
]

import enum


class OfflineDetailedState(enum.IntEnum):
    AVAILABLE = 1
    PUBLISH_ONLY = 2


class ImageReadinessDetailedState(enum.IntEnum):
    READY = 1
    NOT_READY = 2
    GETTING_READY = 3


class CalibrationDetailedState(enum.IntEnum):
    DISABLED = 1
    ENABLED = 2
    INTEGRATING = 3


class ShutterDetailedState(enum.IntEnum):
    CLOSED = 1
    OPEN = 2
    CLOSING = 3
    OPENING = 4


class CCSCommandState(enum.IntEnum):
    IDLE = 1
    BUSY = 2


class RaftsDetailedState(enum.IntEnum):
    NEEDS_CLEAR = 1
    CLEARING = 2
    INTEGRATING = 3
    READING_OUT = 4
    QUIESCENT = 5


class CCDType(enum.IntEnum):
    E2V = 1
    ITL = 2
